@@ -3,10 +3,22 @@ from __future__ import print_function
 import traceback
 import sys
 import io
-from io import StringIO
+import json
 
+from contextlib import contextmanager
 from compliance_checker.suite import CheckSuite
 
+# Py 3.4+ has contextlib.redirect_stdout to redirect stdout to a different
+# stream, but use this decorated function in order to redirect output in
+# previous versions
+@contextmanager
+def stdout_redirector(stream):
+    old_stdout = sys.stdout
+    sys.stdout = stream
+    try:
+        yield
+    finally:
+        sys.stdout = old_stdout
 
 class ComplianceChecker(object):
     """
@@ -16,7 +28,9 @@ class ComplianceChecker(object):
     the command line or can be used via import.
     """
     @classmethod
-    def run_checker(cls, ds_loc, checker_names, verbose, criteria, output_filename='stdout', output_format='stdout'):
+    def run_checker(cls, ds_loc, checker_names, verbose, criteria,
+                    skip_checks=None, output_filename='-',
+                    output_format='text'):
         """
         Static check runner.
 
@@ -25,13 +39,16 @@ class ComplianceChecker(object):
         @param  verbose         Verbosity of the output (0, 1, 2)
         @param  criteria        Determines failure (lenient, normal, strict)
         @param  output_filename Path to the file for output
+        @param  skip_checks     Names of checks to skip
         @param  output_format   Format of the output
 
         @returns                If the tests failed (based on the criteria)
         """
         cs = CheckSuite()
         ds = cs.load_dataset(ds_loc)
-        score_groups = cs.run(ds, *checker_names)
+
+        score_groups = cs.run(ds, [] if skip_checks is None else skip_checks,
+                              *checker_names)
 
         if criteria == 'normal':
             limit = 2
@@ -40,8 +57,16 @@ class ComplianceChecker(object):
         elif criteria == 'lenient':
             limit = 3
 
-        if output_filename == '-' and output_format == 'text':
-            groups = cls.stdout_output(cs, score_groups, verbose, limit)
+        if output_format == 'text':
+            if output_filename == '-':
+                groups = cls.stdout_output(cs, score_groups, verbose, limit)
+            # need to redirect output from stdout since print functions are
+            # presently used to generate the standard report output
+            else:
+                with io.open(output_filename, 'w', encoding='utf-8') as f:
+                    with stdout_redirector(f):
+                        groups = cls.stdout_output(cs, score_groups, verbose,
+                                                   limit)
 
         elif output_format == 'html':
             groups = cls.html_output(cs, score_groups, output_filename, ds_loc, limit)
@@ -67,6 +92,7 @@ class ComplianceChecker(object):
         @param verbose      Integer value for verbosity level
         @param limit        The degree of strictness, 1 being the strictest, and going up from there.
         '''
+
         for checker, rpair in score_groups.items():
             groups, errors = rpair
             score_list, points, out_of = cs.standard_output(limit, checker, groups)
@@ -89,7 +115,7 @@ class ComplianceChecker(object):
         for checker, rpair in score_groups.items():
             groups, errors = rpair
             if output_filename == '-':
-                f = StringIO()
+                f = io.StringIO()
                 cs.html_output(checker, groups, f, ds_loc, limit)
                 f.seek(0)
                 print(f.read())
@@ -109,16 +135,19 @@ class ComplianceChecker(object):
         @param ds_loc          Location of the source dataset
         @param limit           The degree of strictness, 1 being the strictest, and going up from there.
         '''
-        for checker, rpair in score_groups.items():
+        results = {}
+        for i, (checker, rpair) in enumerate(score_groups.items()):
             groups, errors = rpair
-            if output_filename == '-':
-                f = StringIO()
-                cs.json_output(checker, groups, f, ds_loc, limit)
-                f.seek(0)
-                print(f.read())
-            else:
-                with io.open(output_filename, 'w', encoding='utf8') as f:
-                    cs.json_output(checker, groups, f, ds_loc, limit)
+            results[checker] = cs.dict_output(
+                checker, groups, ds_loc, limit
+            )
+        json_results = json.dumps(results, indent=2, ensure_ascii=False)
+
+        if output_filename == '-':
+            print(json_results)
+        else:
+            with io.open(output_filename, 'w', encoding='utf8') as f:
+                f.write(json_results)
 
         return groups
 
