@@ -18,13 +18,12 @@ from owslib.sos import SensorObservationService
 from owslib.swe.sensor.sml import SensorML
 try:
     from urlparse import urlparse
-except:
+except ImportError:
     from urllib.parse import urlparse
 from datetime import datetime
 import requests
 import textwrap
 import codecs
-from tempfile import gettempdir
 
 # Ensure output is encoded as Unicode when checker output is redirected or piped
 if sys.stdout.encoding is None:
@@ -70,15 +69,18 @@ class CheckSuite(object):
             cls.checkers[spec] = cls.checkers[spec + ':latest'] = \
                 cls.checkers[':'.join((spec, latest_version))]
 
-    def _get_checks(self, checkclass):
+    def _get_checks(self, checkclass, skip_checks):
         """
-        Helper method to retreive check methods from a Checker class.
+        Helper method to retreive check methods from a Checker class.  Excludes
+        any checks in `skip_checks`.
 
         The name of the methods in the Checker class should start with "check_" for this
         method to find them.
         """
         meths = inspect.getmembers(checkclass, inspect.ismethod)
-        return [x[1] for x in meths if x[0].startswith("check_")]
+        # return all check methods not among the skipped checks
+        return [x[1] for x in meths if x[0].startswith("check_") and
+                x[0] not in skip_checks]
 
     def _run_check(self, check_method, ds):
         val = check_method(ds)
@@ -117,7 +119,7 @@ class CheckSuite(object):
 
         return valid
 
-    def run(self, ds, *checker_names):
+    def run(self, ds, skip_checks, *checker_names):
         """
         Runs this CheckSuite on the dataset with all the passed Checker instances.
 
@@ -135,7 +137,7 @@ class CheckSuite(object):
             checker = checker_class()
             checker.setup(ds)
 
-            checks             = self._get_checks(checker)
+            checks             = self._get_checks(checker, skip_checks)
             vals               = []
             errs               = {}   # check method name -> (exc, traceback)
 
@@ -242,22 +244,18 @@ class CheckSuite(object):
         aggregates['source_name']       = source_name
         return aggregates
 
-    def json_output(self, check_name, groups, file_object, source_name, limit):
+    def dict_output(self, check_name, groups, source_name, limit):
         '''
         Builds the results into a JSON structure and writes it to the file buffer.
 
         @param check_name      The test which was run
         @param groups          List of results from compliance checker
         @param output_filename Path to file to save output
-        @param file_object     A python file object where the output should be written to
         @param source_name     Source of the dataset, used for title
         @param limit           Integer value for limiting output
         '''
         aggregates = self.build_structure(check_name, groups, source_name, limit)
-        aggregates = self.serialize(aggregates)
-        json_string = json.dumps(aggregates, ensure_ascii=False)
-        file_object.write(json_string)
-        return
+        return self.serialize(aggregates)
 
     def serialize(self, o):
         '''
@@ -477,14 +475,17 @@ class CheckSuite(object):
             if res.children:
                 self.reasoning_routine(res.children, indent + 1, False)
 
-    def process_doc(doc):
+    def process_doc(self, doc):
         """
         Attempt to parse an xml string conforming to either an SOS or SensorML
         dataset and return the results
         """
-        xml_doc = ET.fromstring(str(doc))
+        xml_doc = ET.fromstring(doc)
         if xml_doc.tag == "{http://www.opengis.net/sos/1.0}Capabilities":
-            ds = SensorObservationService(ds_str, xml=str(doc))
+            ds = SensorObservationService(None, xml=doc)
+            # SensorObservationService does not store the etree doc root,
+            # so maybe use monkey patching here for now?
+            ds._root = xml_doc
 
         elif xml_doc.tag == "{http://www.opengis.net/sensorML/1.0.1}SensorML":
             ds = SensorML(xml_doc)
@@ -524,7 +525,10 @@ class CheckSuite(object):
                 r = requests.get(ds_str)
                 r.raise_for_status()
 
-                doc = r.text
+                # need to use content to get bytes, as text will return unicode
+                # in Python3, which will break etree.fromstring if encoding
+                # is also declared in the XML doc
+                doc = r.content
             else:
                 raise Exception("Could not understand response code %s and content-type %s" % (rhead.status_code, rhead.headers.get('content-type', 'none')))
         else:
@@ -564,7 +568,7 @@ class CheckSuite(object):
                 '''
                 if os.path.splitext(filename)[-1] == '.cdl':
                     return True
-                if data.startswith('netcdf') or 'dimensions' in data:
+                if data.startswith(b'netcdf') or b'dimensions' in data:
                     return True
                 return False
 
@@ -577,10 +581,10 @@ class CheckSuite(object):
                     ds_str = self.generate_dataset(ds_str)
                 else:
                     f.seek(0)
-                    doc = "".join(f.readlines())
+                    doc = f.read()
 
         if doc is not None:
-            ds = process_doc(doc)
+            ds = self.process_doc(doc)
         else:
             # no doc? try the dataset constructor
             ds = Dataset(ds_str)
